/**
 * Created by PanJiaChen on 16/11/18.
 */
const CryptoJS = require('crypto-js'); // js
/**
 * Parse the time to string
 * @param {(Object|string|number)} time
 * @param {string} cFormat
 * @returns {string | null}
 */
export function parseTime(time, cFormat) {
  if (arguments.length === 0 || !time) {
    return null
  }
  const format = cFormat || '{y}-{m}-{d} {h}:{i}:{s}'
  let date
  if (typeof time === 'object') {
    date = time
  } else {
    if ((typeof time === 'string')) {
      if ((/^[0-9]+$/.test(time))) {
        // support "1548221490638"
        time = parseInt(time)
      } else {
        // support safari
        // https://stackoverflow.com/questions/4310953/invalid-date-in-safari
        time = time.replace(new RegExp(/-/gm), '/')
      }
    }

    if ((typeof time === 'number') && (time.toString().length === 10)) {
      time = time * 1000
    }
    date = new Date(time)
  }
  const formatObj = {
    y: date.getFullYear(),
    m: date.getMonth() + 1,
    d: date.getDate(),
    h: date.getHours(),
    i: date.getMinutes(),
    s: date.getSeconds(),
    a: date.getDay()
  }
  const time_str = format.replace(/{([ymdhisa])+}/g, (result, key) => {
    const value = formatObj[key]
    // Note: getDay() returns 0 on Sunday
    if (key === 'a') { return ['日', '一', '二', '三', '四', '五', '六'][value ] }
    return value.toString().padStart(2, '0')
  })
  return time_str
}

/**
 * @param {number} time
 * @param {string} option
 * @returns {string}
 */
export function formatTime(time, option) {
  if (('' + time).length === 10) {
    time = parseInt(time) * 1000
  } else {
    time = +time
  }
  const d = new Date(time)
  const now = Date.now()

  const diff = (now - d) / 1000

  if (diff < 30) {
    return '刚刚'
  } else if (diff < 3600) {
    // less 1 hour
    return Math.ceil(diff / 60) + '分钟前'
  } else if (diff < 3600 * 24) {
    return Math.ceil(diff / 3600) + '小时前'
  } else if (diff < 3600 * 24 * 2) {
    return '1天前'
  }
  if (option) {
    return parseTime(time, option)
  } else {
    return (
      d.getMonth() +
      1 +
      '月' +
      d.getDate() +
      '日' +
      d.getHours() +
      '时' +
      d.getMinutes() +
      '分'
    )
  }
}

/**
 * @param {string} url
 * @returns {Object}
 */
export function param2Obj(url) {
  const search = decodeURIComponent(url.split('?')[1]).replace(/\+/g, ' ')
  if (!search) {
    return {}
  }
  const obj = {}
  const searchArr = search.split('&')
  searchArr.forEach(v => {
    const index = v.indexOf('=')
    if (index !== -1) {
      const name = v.substring(0, index)
      const val = v.substring(index + 1, v.length)
      obj[name] = val
    }
  })
  return obj
}


//获取当前时间
export function getTime(num) {
  let s = new Date().getTime() + num * 1000 * 60 * 60 * 24
  let date = new Date(s)
  let year = date.getFullYear();
  let month = date.getMonth() + 1 >= 10 ? date.getMonth() + 1 : '0' + (date.getMonth() + 1);
  let day = date.getDate() >= 10 ? date.getDate() : '0' + date.getDate();
  let hour = date.getHours() >= 10 ? date.getHours() : '0' + date.getHours();
  let minute = date.getMinutes() >= 10 ? date.getMinutes() : '0' + date.getMinutes();
  let second = date.getSeconds() >= 10 ? date.getSeconds() : '0' + date.getSeconds();
  let time = `${year}-${month}-${day}`
  // let time = `${year}-${month}-${day} ${hour}:${minute}:${second}`
  return time;
}

//获取当前时间
export function timeFormat(num) {
  let date = new Date(num)
  let year = date.getFullYear();
  let month = date.getMonth() + 1 >= 10 ? date.getMonth() + 1 : '0' + (date.getMonth() + 1);
  let day = date.getDate() >= 10 ? date.getDate() : '0' + date.getDate();
  let hour = date.getHours() >= 10 ? date.getHours() : '0' + date.getHours();
  let minute = date.getMinutes() >= 10 ? date.getMinutes() : '0' + date.getMinutes();
  let second = date.getSeconds() >= 10 ? date.getSeconds() : '0' + date.getSeconds();
  let time = `${year}-${month}-${day} ${hour}:${minute}:${second}`

  return time;
}

//防抖debounce代码：
export function debounce(fn,delay=500) {
  var timeout = null; // 创建一个标记用来存放定时器的返回值
  return function (e) {
      // 每当用户输入的时候把前一个 setTimeout clear 掉
      clearTimeout(timeout); 
      // 然后又创建一个新的 setTimeout, 这样就能保证interval 间隔内如果时间持续触发，就不会执行 fn 函数
      timeout = setTimeout(() => {
          fn.apply(this, arguments);
      }, delay);
  };
}

/**
 * aes加密
 * @param {*} word 
 * @param {*} key 
 * @returns 
 */
export function setAes(pas,k) {
  var b = CryptoJS.enc.Base64
  var key = CryptoJS.enc.Utf8.parse(k) //秘钥
  var srcs = CryptoJS.enc.Utf8.parse(pas)
  var encrypted = CryptoJS.AES.encrypt(srcs, key, {
      mode: CryptoJS.mode.ECB,
      padding: CryptoJS.pad.Pkcs7
  })
  return b.stringify(encrypted.ciphertext)
}

/**
 * 根据window.location判断是否是本地环境
 * @returns Boolean
 */
export function isLocal() {
   // 获取当前 URL 的主机部分
   const hostname = new URL(window.location.href).hostname;

   // 匹配本地地址
   const cBlockRegex = /^(localhost|127.0.0.1|192\.168\.|10\.|172\.(1[6-9]|2[0-9]|3[0-1])\.)/;
 
   // 检查当前 URL 的主机部分是否匹配 C 段网络
   return cBlockRegex.test(hostname);
}